.. _overview:

Architecture overview
=====================

These documents describe the library structure and the rationale behind its design. :ref:`introduction-overview`
presents the TidyMS data model and data flow, which combined define how MS data is transformed. The
subsequent sections describe the data model and data flow in detail for each pipeline type.

.. toctree::
   :maxdepth: 1

   overview/introduction
   overview/sample
   overview/assay
   overview/matrix
